@@ -33,10 +33,10 @@ import json
 import time
 import adafruit_minimqtt as minimqtt
 from adafruit_minimqtt import MQTT
-import circuitpython_parse as parse
 import adafruit_logging as logging
-from .device_registration import DeviceRegistration
 from .iot_error import IoTError
+from .keys import compute_derived_symmetric_key
+from .quote import quote
 from . import constants
 
 # pylint: disable=R0903
@@ -107,8 +107,8 @@ class IoTMQTT:
     def _gen_sas_token(self) -> str:
         token_expiry = int(time.time() + self._token_expires)
         uri = self._hostname + "%2Fdevices%2F" + self._device_id
-        signed_hmac_sha256 = DeviceRegistration.compute_derived_symmetric_key(self._key, uri + "\n" + str(token_expiry))
-        signature = parse.quote(signed_hmac_sha256, "~()*!.'")
+        signed_hmac_sha256 = compute_derived_symmetric_key(self._key, uri + "\n" + str(token_expiry))
+        signature = quote(signed_hmac_sha256, "~()*!.'")
         if signature.endswith("\n"):  # somewhere along the crypto chain a newline is inserted
             signature = signature[:-1]
         token = "SharedAccessSignature sr={}&sig={}&se={}".format(uri, signature, token_expiry)
@@ -227,6 +227,7 @@ class IoTMQTT:
             method_name = topic[len_temp : topic.find("/", len_temp + 1)]
 
         ret = self._callback.direct_method_invoked(method_name, msg)
+        gc.collect()
 
         ret_code = 200
         ret_message = "{}"
@@ -253,13 +254,14 @@ class IoTMQTT:
             properties[key_value[0]] = key_value[1]
 
         self._callback.cloud_to_device_message_received(msg, properties)
+        gc.collect()
 
     # pylint: disable=W0702, R0912
     def _on_message(self, client, msg_topic, payload) -> None:
         topic = ""
         msg = None
 
-        self._logger.info("- iot_mqtt :: _on_message :: payload(" + str(payload) + ")")
+        self._logger.info("- iot_mqtt :: _on_message")
 
         if payload is not None:
             try:
@@ -439,6 +441,7 @@ class IoTMQTT:
             return
 
         self._mqtts.loop()
+        gc.collect()
 
     def send_device_to_cloud_message(self, message, system_properties: dict = None) -> None:
         """Send a device to cloud message from this device to Azure IoT Hub
